@@ -1,6 +1,9 @@
 extern crate pkg_config;
 extern crate cmake;
 
+#[cfg(target_env = "msvc")]
+extern crate vcpkg;
+
 use std::env;
 use std::fs::File;
 use std::io::prelude::*;
@@ -8,6 +11,10 @@ use std::path::{PathBuf, Path};
 use std::process::Command;
 
 fn main() {
+    if try_vcpkg() {
+        return;
+    }
+
     register_dep("Z");
     register_dep("OPENSSL");
 
@@ -55,6 +62,11 @@ fn main() {
         }
     }
 
+    // Homebrew deprecated OpenSSL and deliberately hides it from cmake, requiring such opt-in
+    if target.contains("darwin") && Path::new("/usr/local/opt/openssl/include/openssl/ssl.h").exists() {
+        cfg.define("OPENSSL_ROOT_DIR", "/usr/local/opt/openssl/");
+    }
+
     let dst = cfg.define("BUILD_SHARED_LIBS", "OFF")
                  .define("ENABLE_ZLIB_COMPRESSION", "ON")
                  .define("CMAKE_INSTALL_LIBDIR", "lib")
@@ -101,7 +113,9 @@ fn register_dep(dep: &str) {
         return
     }
     if let Some(s) = env::var_os(&format!("DEP_{}_INCLUDE", dep)) {
-        let path = Path::new(&s).join("../lib/pkgconfig");
+        let root = Path::new(&s).parent().unwrap();
+        env::set_var(&format!("DEP_{}_ROOT", dep), root);
+        let path = root.join("lib/pkgconfig");
         if path.exists() {
             prepend("PKG_CONFIG_PATH", path);
             return
@@ -115,3 +129,30 @@ fn prepend(var: &str, val: PathBuf) {
     v.extend(env::split_paths(&prefix));
     env::set_var(var, &env::join_paths(v).unwrap());
 }
+
+#[cfg(not(target_env = "msvc"))]
+fn try_vcpkg() -> bool { false }
+
+#[cfg(target_env = "msvc")]
+fn try_vcpkg() -> bool {
+    vcpkg::Config::new()
+        .emit_includes(true)
+        .probe("libssh2").map(|_| {
+
+        // found libssh2 which depends on openssl and zlib
+        vcpkg::Config::new()
+            .lib_name("libeay32")
+            .lib_name("ssleay32")
+            .probe("openssl").expect("configured libssh2 from vcpkg but could not \
+                                      find openssl libraries that it depends on");
+
+        vcpkg::Config::new()
+            .lib_names("zlib", "zlib1")
+            .probe("zlib").expect("configured libssh2 from vcpkg but could not \
+                                   find the zlib library that it depends on");
+
+        println!("cargo:rustc-link-lib=crypt32");
+        println!("cargo:rustc-link-lib=gdi32");
+        println!("cargo:rustc-link-lib=user32");
+    }).is_ok()
+}
